# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'PolicyStatement',
    'GetGroupsGroupResult',
    'GetPoliciesPolicyResult',
    'GetPolicyDocumentStatementResult',
    'GetPolicyDocumentStatementConditionResult',
    'GetPolicyDocumentStatementPrincipalResult',
    'GetRolePolicyAttachmentsAttachmentResult',
    'GetRolesRoleResult',
    'GetSamlProvidersProviderResult',
    'GetSystemPolicysPolicyResult',
    'GetUsersUserResult',
]

@pulumi.output_type
class PolicyStatement(dict):
    def __init__(__self__, *,
                 actions: Sequence[builtins.str],
                 effect: builtins.str,
                 resources: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] actions: (It has been deprecated since version 1.49.0, and use field `document` to replace.) List of operations for the `resource`. The format of each item in this list is `${service}:${action_name}`, such as `oss:ListBuckets` and `ecs:Describe*`. The `${service}` can be `ecs`, `oss`, `ots` and so on, the `${action_name}` refers to the name of an api interface which related to the `${service}`.
        :param builtins.str effect: (It has been deprecated since version 1.49.0, and use field `document` to replace.) This parameter indicates whether or not the `action` is allowed. Valid values are `Allow` and `Deny`.
        :param Sequence[builtins.str] resources: (It has been deprecated since version 1.49.0, and use field `document` to replace.) List of specific objects which will be authorized. The format of each item in this list is `acs:${service}:${region}:${account_id}:${relative_id}`, such as `acs:ecs:*:*:instance/inst-002` and `acs:oss:*:1234567890000:mybucket`. The `${service}` can be `ecs`, `oss`, `ots` and so on, the `${region}` is the region info which can use `*` replace when it is not supplied, the `${account_id}` refers to someone`s Alicloud account id or you can use `*` to replace, the `${relative_id}` is the resource description section which related to the `${service}`.
        """
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "effect", effect)
        pulumi.set(__self__, "resources", resources)

    @property
    @pulumi.getter
    def actions(self) -> Sequence[builtins.str]:
        """
        (It has been deprecated since version 1.49.0, and use field `document` to replace.) List of operations for the `resource`. The format of each item in this list is `${service}:${action_name}`, such as `oss:ListBuckets` and `ecs:Describe*`. The `${service}` can be `ecs`, `oss`, `ots` and so on, the `${action_name}` refers to the name of an api interface which related to the `${service}`.
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def effect(self) -> builtins.str:
        """
        (It has been deprecated since version 1.49.0, and use field `document` to replace.) This parameter indicates whether or not the `action` is allowed. Valid values are `Allow` and `Deny`.
        """
        return pulumi.get(self, "effect")

    @property
    @pulumi.getter
    def resources(self) -> Sequence[builtins.str]:
        """
        (It has been deprecated since version 1.49.0, and use field `document` to replace.) List of specific objects which will be authorized. The format of each item in this list is `acs:${service}:${region}:${account_id}:${relative_id}`, such as `acs:ecs:*:*:instance/inst-002` and `acs:oss:*:1234567890000:mybucket`. The `${service}` can be `ecs`, `oss`, `ots` and so on, the `${region}` is the region info which can use `*` replace when it is not supplied, the `${account_id}` refers to someone`s Alicloud account id or you can use `*` to replace, the `${relative_id}` is the resource description section which related to the `${service}`.
        """
        return pulumi.get(self, "resources")


@pulumi.output_type
class GetGroupsGroupResult(dict):
    def __init__(__self__, *,
                 comments: builtins.str,
                 name: builtins.str):
        """
        :param builtins.str comments: Comments of the group.
        :param builtins.str name: Name of the group.
        """
        pulumi.set(__self__, "comments", comments)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def comments(self) -> builtins.str:
        """
        Comments of the group.
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the group.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetPoliciesPolicyResult(dict):
    def __init__(__self__, *,
                 attachment_count: builtins.int,
                 create_date: builtins.str,
                 default_version: builtins.str,
                 description: builtins.str,
                 document: builtins.str,
                 id: builtins.str,
                 name: builtins.str,
                 policy_document: builtins.str,
                 policy_name: builtins.str,
                 type: builtins.str,
                 update_date: builtins.str,
                 user_name: builtins.str,
                 version_id: builtins.str):
        """
        :param builtins.int attachment_count: Attachment count of the policy.
        :param builtins.str create_date: Creation date of the policy.
        :param builtins.str default_version: Default version of the policy.
        :param builtins.str description: Description of the policy.
        :param builtins.str document: Policy document of the policy.
        :param builtins.str id: ID of the policy.
        :param builtins.str name: Name of the policy.
        :param builtins.str policy_document: Policy document of the policy.
        :param builtins.str policy_name: Name of the policy.
        :param builtins.str type: Filter results by a specific policy type. Valid values are `Custom` and `System`.
        :param builtins.str update_date: Update date of the policy.
        :param builtins.str user_name: Filter results by a specific user name. Returned policies are attached to the specified user.
        :param builtins.str version_id: The ID of default policy.
        """
        pulumi.set(__self__, "attachment_count", attachment_count)
        pulumi.set(__self__, "create_date", create_date)
        pulumi.set(__self__, "default_version", default_version)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "document", document)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "policy_document", policy_document)
        pulumi.set(__self__, "policy_name", policy_name)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "update_date", update_date)
        pulumi.set(__self__, "user_name", user_name)
        pulumi.set(__self__, "version_id", version_id)

    @property
    @pulumi.getter(name="attachmentCount")
    def attachment_count(self) -> builtins.int:
        """
        Attachment count of the policy.
        """
        return pulumi.get(self, "attachment_count")

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> builtins.str:
        """
        Creation date of the policy.
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter(name="defaultVersion")
    def default_version(self) -> builtins.str:
        """
        Default version of the policy.
        """
        return pulumi.get(self, "default_version")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the policy.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def document(self) -> builtins.str:
        """
        Policy document of the policy.
        """
        return pulumi.get(self, "document")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        ID of the policy.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the policy.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> builtins.str:
        """
        Policy document of the policy.
        """
        return pulumi.get(self, "policy_document")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> builtins.str:
        """
        Name of the policy.
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        Filter results by a specific policy type. Valid values are `Custom` and `System`.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> builtins.str:
        """
        Update date of the policy.
        """
        return pulumi.get(self, "update_date")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        Filter results by a specific user name. Returned policies are attached to the specified user.
        """
        return pulumi.get(self, "user_name")

    @property
    @pulumi.getter(name="versionId")
    def version_id(self) -> builtins.str:
        """
        The ID of default policy.
        """
        return pulumi.get(self, "version_id")


@pulumi.output_type
class GetPolicyDocumentStatementResult(dict):
    def __init__(__self__, *,
                 actions: Sequence[builtins.str],
                 conditions: Optional[Sequence['outputs.GetPolicyDocumentStatementConditionResult']] = None,
                 effect: Optional[builtins.str] = None,
                 principals: Optional[Sequence['outputs.GetPolicyDocumentStatementPrincipalResult']] = None,
                 resources: Optional[Sequence[builtins.str]] = None):
        """
        :param Sequence[builtins.str] actions: Action of the RAM policy document. If you want to create a RAM role policy document, it must be `["sts:AssumeRole"]`.
        :param Sequence['GetPolicyDocumentStatementConditionArgs'] conditions: Specifies the condition that are required for a policy to take effect. See `condition` below.
        :param builtins.str effect: This parameter indicates whether or not the `action` is allowed. Valid values are `Allow` and `Deny`. Default value is `Allow`. If you want to create a RAM role policy document, it must be `Allow`.
        :param Sequence['GetPolicyDocumentStatementPrincipalArgs'] principals: Principal of the RAM policy document. If you want to create a RAM role policy document, it must be set. See `principal` below.
        :param Sequence[builtins.str] resources: List of specific objects which will be authorized. If you want to create a RAM policy document, it must be set.
        """
        pulumi.set(__self__, "actions", actions)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if effect is not None:
            pulumi.set(__self__, "effect", effect)
        if principals is not None:
            pulumi.set(__self__, "principals", principals)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)

    @property
    @pulumi.getter
    def actions(self) -> Sequence[builtins.str]:
        """
        Action of the RAM policy document. If you want to create a RAM role policy document, it must be `["sts:AssumeRole"]`.
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def conditions(self) -> Optional[Sequence['outputs.GetPolicyDocumentStatementConditionResult']]:
        """
        Specifies the condition that are required for a policy to take effect. See `condition` below.
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter
    def effect(self) -> Optional[builtins.str]:
        """
        This parameter indicates whether or not the `action` is allowed. Valid values are `Allow` and `Deny`. Default value is `Allow`. If you want to create a RAM role policy document, it must be `Allow`.
        """
        return pulumi.get(self, "effect")

    @property
    @pulumi.getter
    def principals(self) -> Optional[Sequence['outputs.GetPolicyDocumentStatementPrincipalResult']]:
        """
        Principal of the RAM policy document. If you want to create a RAM role policy document, it must be set. See `principal` below.
        """
        return pulumi.get(self, "principals")

    @property
    @pulumi.getter
    def resources(self) -> Optional[Sequence[builtins.str]]:
        """
        List of specific objects which will be authorized. If you want to create a RAM policy document, it must be set.
        """
        return pulumi.get(self, "resources")


@pulumi.output_type
class GetPolicyDocumentStatementConditionResult(dict):
    def __init__(__self__, *,
                 operator: builtins.str,
                 values: Sequence[builtins.str],
                 variable: builtins.str):
        """
        :param builtins.str operator: The operator of the condition.
        :param Sequence[builtins.str] values: The values of the condition.
        :param builtins.str variable: The variable of the condition.
        """
        pulumi.set(__self__, "operator", operator)
        pulumi.set(__self__, "values", values)
        pulumi.set(__self__, "variable", variable)

    @property
    @pulumi.getter
    def operator(self) -> builtins.str:
        """
        The operator of the condition.
        """
        return pulumi.get(self, "operator")

    @property
    @pulumi.getter
    def values(self) -> Sequence[builtins.str]:
        """
        The values of the condition.
        """
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def variable(self) -> builtins.str:
        """
        The variable of the condition.
        """
        return pulumi.get(self, "variable")


@pulumi.output_type
class GetPolicyDocumentStatementPrincipalResult(dict):
    def __init__(__self__, *,
                 entity: builtins.str,
                 identifiers: Sequence[builtins.str]):
        """
        :param builtins.str entity: The trusted entity. Valid values: `RAM`, `Service` and `Federated`.
        :param Sequence[builtins.str] identifiers: The identifiers of the principal.
        """
        pulumi.set(__self__, "entity", entity)
        pulumi.set(__self__, "identifiers", identifiers)

    @property
    @pulumi.getter
    def entity(self) -> builtins.str:
        """
        The trusted entity. Valid values: `RAM`, `Service` and `Federated`.
        """
        return pulumi.get(self, "entity")

    @property
    @pulumi.getter
    def identifiers(self) -> Sequence[builtins.str]:
        """
        The identifiers of the principal.
        """
        return pulumi.get(self, "identifiers")


@pulumi.output_type
class GetRolePolicyAttachmentsAttachmentResult(dict):
    def __init__(__self__, *,
                 attach_date: builtins.str,
                 description: builtins.str,
                 id: builtins.str,
                 policy_name: builtins.str,
                 policy_type: builtins.str):
        """
        :param builtins.str attach_date: The time when the role was attached to the policy.
        :param builtins.str description: The policy description.
        :param builtins.str id: The ID of the resource supplied above. The value is formulated as `role:<policy_name>:<policy_type>:<role_name>`.
        :param builtins.str policy_name: The name of the policy.
        :param builtins.str policy_type: Policy type.- Custom: Custom policy.- System: System policy.
        """
        pulumi.set(__self__, "attach_date", attach_date)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "policy_name", policy_name)
        pulumi.set(__self__, "policy_type", policy_type)

    @property
    @pulumi.getter(name="attachDate")
    def attach_date(self) -> builtins.str:
        """
        The time when the role was attached to the policy.
        """
        return pulumi.get(self, "attach_date")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        The policy description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the resource supplied above. The value is formulated as `role:<policy_name>:<policy_type>:<role_name>`.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> builtins.str:
        """
        The name of the policy.
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> builtins.str:
        """
        Policy type.- Custom: Custom policy.- System: System policy.
        """
        return pulumi.get(self, "policy_type")


@pulumi.output_type
class GetRolesRoleResult(dict):
    def __init__(__self__, *,
                 arn: builtins.str,
                 assume_role_policy_document: builtins.str,
                 create_date: builtins.str,
                 description: builtins.str,
                 document: builtins.str,
                 id: builtins.str,
                 name: builtins.str,
                 update_date: builtins.str):
        """
        :param builtins.str arn: Resource descriptor of the role.
        :param builtins.str assume_role_policy_document: Authorization strategy of the role. This parameter is deprecated and replaced by `document`.
        :param builtins.str create_date: Creation date of the role.
        :param builtins.str description: Description of the role.
        :param builtins.str document: Authorization strategy of the role.
        :param builtins.str id: ID of the role.
        :param builtins.str name: Name of the role.
        :param builtins.str update_date: Update date of the role.
        """
        pulumi.set(__self__, "arn", arn)
        pulumi.set(__self__, "assume_role_policy_document", assume_role_policy_document)
        pulumi.set(__self__, "create_date", create_date)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "document", document)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter
    def arn(self) -> builtins.str:
        """
        Resource descriptor of the role.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter(name="assumeRolePolicyDocument")
    def assume_role_policy_document(self) -> builtins.str:
        """
        Authorization strategy of the role. This parameter is deprecated and replaced by `document`.
        """
        return pulumi.get(self, "assume_role_policy_document")

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> builtins.str:
        """
        Creation date of the role.
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the role.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def document(self) -> builtins.str:
        """
        Authorization strategy of the role.
        """
        return pulumi.get(self, "document")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        ID of the role.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the role.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> builtins.str:
        """
        Update date of the role.
        """
        return pulumi.get(self, "update_date")


@pulumi.output_type
class GetSamlProvidersProviderResult(dict):
    def __init__(__self__, *,
                 arn: builtins.str,
                 description: builtins.str,
                 encodedsaml_metadata_document: builtins.str,
                 id: builtins.str,
                 saml_provider_name: builtins.str,
                 update_date: builtins.str):
        """
        :param builtins.str arn: The Alibaba Cloud Resource Name (ARN) of the IdP.
        :param builtins.str description: The description of SAML Provider.
        :param builtins.str encodedsaml_metadata_document: The encodedsaml metadata document.
        :param builtins.str id: The ID of the SAML Provider.
        :param builtins.str saml_provider_name: The saml provider name.
        :param builtins.str update_date: The update time.
        """
        pulumi.set(__self__, "arn", arn)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "encodedsaml_metadata_document", encodedsaml_metadata_document)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "saml_provider_name", saml_provider_name)
        pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter
    def arn(self) -> builtins.str:
        """
        The Alibaba Cloud Resource Name (ARN) of the IdP.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        The description of SAML Provider.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="encodedsamlMetadataDocument")
    def encodedsaml_metadata_document(self) -> builtins.str:
        """
        The encodedsaml metadata document.
        """
        return pulumi.get(self, "encodedsaml_metadata_document")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the SAML Provider.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="samlProviderName")
    def saml_provider_name(self) -> builtins.str:
        """
        The saml provider name.
        """
        return pulumi.get(self, "saml_provider_name")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> builtins.str:
        """
        The update time.
        """
        return pulumi.get(self, "update_date")


@pulumi.output_type
class GetSystemPolicysPolicyResult(dict):
    def __init__(__self__, *,
                 attachment_count: builtins.int,
                 create_time: builtins.str,
                 description: builtins.str,
                 id: builtins.str,
                 policy_name: builtins.str,
                 policy_type: builtins.str,
                 update_date: builtins.str):
        """
        :param builtins.int attachment_count: Number of references.
        :param builtins.str create_time: Creation time.
        :param builtins.str description: The permission policy description.
        :param builtins.str id: The ID of the resource supplied above.
        :param builtins.str policy_name: The permission policy name.
        :param builtins.str policy_type: Permission policy type.
        :param builtins.str update_date: Modification time.
        """
        pulumi.set(__self__, "attachment_count", attachment_count)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "policy_name", policy_name)
        pulumi.set(__self__, "policy_type", policy_type)
        pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter(name="attachmentCount")
    def attachment_count(self) -> builtins.int:
        """
        Number of references.
        """
        return pulumi.get(self, "attachment_count")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        The permission policy description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the resource supplied above.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> builtins.str:
        """
        The permission policy name.
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> builtins.str:
        """
        Permission policy type.
        """
        return pulumi.get(self, "policy_type")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> builtins.str:
        """
        Modification time.
        """
        return pulumi.get(self, "update_date")


@pulumi.output_type
class GetUsersUserResult(dict):
    def __init__(__self__, *,
                 create_date: builtins.str,
                 id: builtins.str,
                 last_login_date: builtins.str,
                 name: builtins.str):
        """
        :param builtins.str create_date: Creation date of the user.
        :param builtins.str id: The original id is user's name, but it is user id in 1.37.0+.
        :param builtins.str last_login_date: (Removed) Last login date of the user. Removed from version 1.79.0.
        :param builtins.str name: Name of the user.
        """
        pulumi.set(__self__, "create_date", create_date)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "last_login_date", last_login_date)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> builtins.str:
        """
        Creation date of the user.
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The original id is user's name, but it is user id in 1.37.0+.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastLoginDate")
    def last_login_date(self) -> builtins.str:
        """
        (Removed) Last login date of the user. Removed from version 1.79.0.
        """
        return pulumi.get(self, "last_login_date")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name of the user.
        """
        return pulumi.get(self, "name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PolicyArgs', 'Policy']

@pulumi.input_type
class PolicyArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 document: Optional[pulumi.Input[builtins.str]] = None,
                 force: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 policy_document: Optional[pulumi.Input[builtins.str]] = None,
                 policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 rotate_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 statements: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyStatementArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Policy resource.
        :param pulumi.Input[builtins.str] description: The description of the policy. It can be 1 to 1024 characters in length.
        :param pulumi.Input[builtins.str] document: Field `document` has been deprecated from provider version 1.114.0. New field `policy_document` instead.
        :param pulumi.Input[builtins.bool] force: Specifies whether to force delete the Policy. Default value: `false`. Valid values:
        :param pulumi.Input[builtins.str] name: Field `name` has been deprecated from provider version 1.114.0. New field `policy_name` instead.
        :param pulumi.Input[builtins.str] policy_document: The content of the policy. The maximum length is 6144 bytes.
        :param pulumi.Input[builtins.str] policy_name: The policy name. It can be 1 to 128 characters in length and can contain English letters, digits, and dashes (-).
        :param pulumi.Input[builtins.str] rotate_strategy: The automatic rotation mechanism of policy versions can delete historical policy versions. The default value is None. Valid values:
               - `None`: Turn off the rotation mechanism.
               - `DeleteOldestNonDefaultVersionWhenLimitExceeded`: When the number of permission policy versions exceeds the limit, the oldest and inactive version is deleted.
        :param pulumi.Input[Sequence[pulumi.Input['PolicyStatementArgs']]] statements: Field `statement` has been deprecated from provider version 1.49.0. New field `document` instead. See `statement` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The list of tags on the policy.
        :param pulumi.Input[builtins.str] version: Field `version` has been deprecated from provider version 1.49.0. New field `document` instead.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if document is not None:
            warnings.warn("""Field 'document' has been deprecated from provider version 1.114.0. New field 'policy_document' instead.""", DeprecationWarning)
            pulumi.log.warn("""document is deprecated: Field 'document' has been deprecated from provider version 1.114.0. New field 'policy_document' instead.""")
        if document is not None:
            pulumi.set(__self__, "document", document)
        if force is not None:
            pulumi.set(__self__, "force", force)
        if name is not None:
            warnings.warn("""Field 'name' has been deprecated from provider version 1.114.0. New field 'policy_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""name is deprecated: Field 'name' has been deprecated from provider version 1.114.0. New field 'policy_name' instead.""")
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_document is not None:
            pulumi.set(__self__, "policy_document", policy_document)
        if policy_name is not None:
            pulumi.set(__self__, "policy_name", policy_name)
        if rotate_strategy is not None:
            pulumi.set(__self__, "rotate_strategy", rotate_strategy)
        if statements is not None:
            warnings.warn("""Field 'statement' has been deprecated from version 1.49.0, and use field 'document' to replace. """, DeprecationWarning)
            pulumi.log.warn("""statements is deprecated: Field 'statement' has been deprecated from version 1.49.0, and use field 'document' to replace. """)
        if statements is not None:
            pulumi.set(__self__, "statements", statements)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if version is not None:
            warnings.warn("""Field 'version' has been deprecated from version 1.49.0, and use field 'document' to replace. """, DeprecationWarning)
            pulumi.log.warn("""version is deprecated: Field 'version' has been deprecated from version 1.49.0, and use field 'document' to replace. """)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the policy. It can be 1 to 1024 characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'document' has been deprecated from provider version 1.114.0. New field 'policy_document' instead.""")
    def document(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Field `document` has been deprecated from provider version 1.114.0. New field `policy_document` instead.
        """
        return pulumi.get(self, "document")

    @document.setter
    def document(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "document", value)

    @property
    @pulumi.getter
    def force(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to force delete the Policy. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "force")

    @force.setter
    def force(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "force", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated from provider version 1.114.0. New field 'policy_name' instead.""")
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Field `name` has been deprecated from provider version 1.114.0. New field `policy_name` instead.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The content of the policy. The maximum length is 6144 bytes.
        """
        return pulumi.get(self, "policy_document")

    @policy_document.setter
    def policy_document(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_document", value)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The policy name. It can be 1 to 128 characters in length and can contain English letters, digits, and dashes (-).
        """
        return pulumi.get(self, "policy_name")

    @policy_name.setter
    def policy_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_name", value)

    @property
    @pulumi.getter(name="rotateStrategy")
    def rotate_strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The automatic rotation mechanism of policy versions can delete historical policy versions. The default value is None. Valid values:
        - `None`: Turn off the rotation mechanism.
        - `DeleteOldestNonDefaultVersionWhenLimitExceeded`: When the number of permission policy versions exceeds the limit, the oldest and inactive version is deleted.
        """
        return pulumi.get(self, "rotate_strategy")

    @rotate_strategy.setter
    def rotate_strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rotate_strategy", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'statement' has been deprecated from version 1.49.0, and use field 'document' to replace. """)
    def statements(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PolicyStatementArgs']]]]:
        """
        Field `statement` has been deprecated from provider version 1.49.0. New field `document` instead. See `statement` below.
        """
        return pulumi.get(self, "statements")

    @statements.setter
    def statements(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyStatementArgs']]]]):
        pulumi.set(self, "statements", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The list of tags on the policy.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'version' has been deprecated from version 1.49.0, and use field 'document' to replace. """)
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Field `version` has been deprecated from provider version 1.49.0. New field `document` instead.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)


@pulumi.input_type
class _PolicyState:
    def __init__(__self__, *,
                 attachment_count: Optional[pulumi.Input[builtins.int]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 default_version: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 document: Optional[pulumi.Input[builtins.str]] = None,
                 force: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 policy_document: Optional[pulumi.Input[builtins.str]] = None,
                 policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 rotate_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 statements: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyStatementArgs']]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 version_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Policy resources.
        :param pulumi.Input[builtins.int] attachment_count: Number of attachments of the policy.
        :param pulumi.Input[builtins.str] create_time: (Available since v1.246.0) The create time of the policy.
        :param pulumi.Input[builtins.str] default_version: The default version ID of the policy.
        :param pulumi.Input[builtins.str] description: The description of the policy. It can be 1 to 1024 characters in length.
        :param pulumi.Input[builtins.str] document: Field `document` has been deprecated from provider version 1.114.0. New field `policy_document` instead.
        :param pulumi.Input[builtins.bool] force: Specifies whether to force delete the Policy. Default value: `false`. Valid values:
        :param pulumi.Input[builtins.str] name: Field `name` has been deprecated from provider version 1.114.0. New field `policy_name` instead.
        :param pulumi.Input[builtins.str] policy_document: The content of the policy. The maximum length is 6144 bytes.
        :param pulumi.Input[builtins.str] policy_name: The policy name. It can be 1 to 128 characters in length and can contain English letters, digits, and dashes (-).
        :param pulumi.Input[builtins.str] rotate_strategy: The automatic rotation mechanism of policy versions can delete historical policy versions. The default value is None. Valid values:
               - `None`: Turn off the rotation mechanism.
               - `DeleteOldestNonDefaultVersionWhenLimitExceeded`: When the number of permission policy versions exceeds the limit, the oldest and inactive version is deleted.
        :param pulumi.Input[Sequence[pulumi.Input['PolicyStatementArgs']]] statements: Field `statement` has been deprecated from provider version 1.49.0. New field `document` instead. See `statement` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The list of tags on the policy.
        :param pulumi.Input[builtins.str] type: The type of the policy.
        :param pulumi.Input[builtins.str] version: Field `version` has been deprecated from provider version 1.49.0. New field `document` instead.
        :param pulumi.Input[builtins.str] version_id: The ID of the default policy version.
        """
        if attachment_count is not None:
            pulumi.set(__self__, "attachment_count", attachment_count)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if default_version is not None:
            pulumi.set(__self__, "default_version", default_version)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if document is not None:
            warnings.warn("""Field 'document' has been deprecated from provider version 1.114.0. New field 'policy_document' instead.""", DeprecationWarning)
            pulumi.log.warn("""document is deprecated: Field 'document' has been deprecated from provider version 1.114.0. New field 'policy_document' instead.""")
        if document is not None:
            pulumi.set(__self__, "document", document)
        if force is not None:
            pulumi.set(__self__, "force", force)
        if name is not None:
            warnings.warn("""Field 'name' has been deprecated from provider version 1.114.0. New field 'policy_name' instead.""", DeprecationWarning)
            pulumi.log.warn("""name is deprecated: Field 'name' has been deprecated from provider version 1.114.0. New field 'policy_name' instead.""")
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_document is not None:
            pulumi.set(__self__, "policy_document", policy_document)
        if policy_name is not None:
            pulumi.set(__self__, "policy_name", policy_name)
        if rotate_strategy is not None:
            pulumi.set(__self__, "rotate_strategy", rotate_strategy)
        if statements is not None:
            warnings.warn("""Field 'statement' has been deprecated from version 1.49.0, and use field 'document' to replace. """, DeprecationWarning)
            pulumi.log.warn("""statements is deprecated: Field 'statement' has been deprecated from version 1.49.0, and use field 'document' to replace. """)
        if statements is not None:
            pulumi.set(__self__, "statements", statements)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if version is not None:
            warnings.warn("""Field 'version' has been deprecated from version 1.49.0, and use field 'document' to replace. """, DeprecationWarning)
            pulumi.log.warn("""version is deprecated: Field 'version' has been deprecated from version 1.49.0, and use field 'document' to replace. """)
        if version is not None:
            pulumi.set(__self__, "version", version)
        if version_id is not None:
            pulumi.set(__self__, "version_id", version_id)

    @property
    @pulumi.getter(name="attachmentCount")
    def attachment_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of attachments of the policy.
        """
        return pulumi.get(self, "attachment_count")

    @attachment_count.setter
    def attachment_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "attachment_count", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Available since v1.246.0) The create time of the policy.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="defaultVersion")
    def default_version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The default version ID of the policy.
        """
        return pulumi.get(self, "default_version")

    @default_version.setter
    def default_version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "default_version", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the policy. It can be 1 to 1024 characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'document' has been deprecated from provider version 1.114.0. New field 'policy_document' instead.""")
    def document(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Field `document` has been deprecated from provider version 1.114.0. New field `policy_document` instead.
        """
        return pulumi.get(self, "document")

    @document.setter
    def document(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "document", value)

    @property
    @pulumi.getter
    def force(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether to force delete the Policy. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "force")

    @force.setter
    def force(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "force", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated from provider version 1.114.0. New field 'policy_name' instead.""")
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Field `name` has been deprecated from provider version 1.114.0. New field `policy_name` instead.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The content of the policy. The maximum length is 6144 bytes.
        """
        return pulumi.get(self, "policy_document")

    @policy_document.setter
    def policy_document(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_document", value)

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The policy name. It can be 1 to 128 characters in length and can contain English letters, digits, and dashes (-).
        """
        return pulumi.get(self, "policy_name")

    @policy_name.setter
    def policy_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "policy_name", value)

    @property
    @pulumi.getter(name="rotateStrategy")
    def rotate_strategy(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The automatic rotation mechanism of policy versions can delete historical policy versions. The default value is None. Valid values:
        - `None`: Turn off the rotation mechanism.
        - `DeleteOldestNonDefaultVersionWhenLimitExceeded`: When the number of permission policy versions exceeds the limit, the oldest and inactive version is deleted.
        """
        return pulumi.get(self, "rotate_strategy")

    @rotate_strategy.setter
    def rotate_strategy(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rotate_strategy", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'statement' has been deprecated from version 1.49.0, and use field 'document' to replace. """)
    def statements(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PolicyStatementArgs']]]]:
        """
        Field `statement` has been deprecated from provider version 1.49.0. New field `document` instead. See `statement` below.
        """
        return pulumi.get(self, "statements")

    @statements.setter
    def statements(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PolicyStatementArgs']]]]):
        pulumi.set(self, "statements", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        The list of tags on the policy.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the policy.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'version' has been deprecated from version 1.49.0, and use field 'document' to replace. """)
    def version(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Field `version` has been deprecated from provider version 1.49.0. New field `document` instead.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version", value)

    @property
    @pulumi.getter(name="versionId")
    def version_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the default policy version.
        """
        return pulumi.get(self, "version_id")

    @version_id.setter
    def version_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "version_id", value)


@pulumi.type_token("alicloud:ram/policy:Policy")
class Policy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 document: Optional[pulumi.Input[builtins.str]] = None,
                 force: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 policy_document: Optional[pulumi.Input[builtins.str]] = None,
                 policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 rotate_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 statements: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicyStatementArgs', 'PolicyStatementArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a RAM Policy resource.

        For information about RAM Policy and how to use it, see [What is Policy](https://www.alibabacloud.com/help/en/ram/developer-reference/api-ram-2015-05-01-createpolicy).

        > **NOTE:** Available since v1.0.0.

        > **NOTE:** When you want to destroy this resource forcefully(means remove all the relationships associated with it automatically and then destroy it) without set `force`  with `true` at beginning, you need add `force = true` to configuration file and run `pulumi preview`, then you can delete resource forcefully.

        > **NOTE:** Each policy can own at most 5 versions and the oldest version will be removed after its version achieves 5.

        > **NOTE:** If the policy has multiple versions, all non-default versions will be deleted first when deleting policy.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        # Create a new RAM Policy.
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        policy = alicloud.ram.Policy("policy",
            policy_name=f"tf-example-{default['result']}",
            policy_document=\"\"\"  {
            "Statement": [
              {
                "Action": [
                  "oss:ListObjects",
                  "oss:GetObject"
                ],
                "Effect": "Allow",
                "Resource": [
                  "acs:oss:*:*:mybucket",
                  "acs:oss:*:*:mybucket/*"
                ]
              }
            ],
              "Version": "1"
          }
        \"\"\",
            description="this is a policy test")
        ```

        ## Import

        RAM Policy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ram/policy:Policy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: The description of the policy. It can be 1 to 1024 characters in length.
        :param pulumi.Input[builtins.str] document: Field `document` has been deprecated from provider version 1.114.0. New field `policy_document` instead.
        :param pulumi.Input[builtins.bool] force: Specifies whether to force delete the Policy. Default value: `false`. Valid values:
        :param pulumi.Input[builtins.str] name: Field `name` has been deprecated from provider version 1.114.0. New field `policy_name` instead.
        :param pulumi.Input[builtins.str] policy_document: The content of the policy. The maximum length is 6144 bytes.
        :param pulumi.Input[builtins.str] policy_name: The policy name. It can be 1 to 128 characters in length and can contain English letters, digits, and dashes (-).
        :param pulumi.Input[builtins.str] rotate_strategy: The automatic rotation mechanism of policy versions can delete historical policy versions. The default value is None. Valid values:
               - `None`: Turn off the rotation mechanism.
               - `DeleteOldestNonDefaultVersionWhenLimitExceeded`: When the number of permission policy versions exceeds the limit, the oldest and inactive version is deleted.
        :param pulumi.Input[Sequence[pulumi.Input[Union['PolicyStatementArgs', 'PolicyStatementArgsDict']]]] statements: Field `statement` has been deprecated from provider version 1.49.0. New field `document` instead. See `statement` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The list of tags on the policy.
        :param pulumi.Input[builtins.str] version: Field `version` has been deprecated from provider version 1.49.0. New field `document` instead.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[PolicyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a RAM Policy resource.

        For information about RAM Policy and how to use it, see [What is Policy](https://www.alibabacloud.com/help/en/ram/developer-reference/api-ram-2015-05-01-createpolicy).

        > **NOTE:** Available since v1.0.0.

        > **NOTE:** When you want to destroy this resource forcefully(means remove all the relationships associated with it automatically and then destroy it) without set `force`  with `true` at beginning, you need add `force = true` to configuration file and run `pulumi preview`, then you can delete resource forcefully.

        > **NOTE:** Each policy can own at most 5 versions and the oldest version will be removed after its version achieves 5.

        > **NOTE:** If the policy has multiple versions, all non-default versions will be deleted first when deleting policy.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        # Create a new RAM Policy.
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        policy = alicloud.ram.Policy("policy",
            policy_name=f"tf-example-{default['result']}",
            policy_document=\"\"\"  {
            "Statement": [
              {
                "Action": [
                  "oss:ListObjects",
                  "oss:GetObject"
                ],
                "Effect": "Allow",
                "Resource": [
                  "acs:oss:*:*:mybucket",
                  "acs:oss:*:*:mybucket/*"
                ]
              }
            ],
              "Version": "1"
          }
        \"\"\",
            description="this is a policy test")
        ```

        ## Import

        RAM Policy can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ram/policy:Policy example <id>
        ```

        :param str resource_name: The name of the resource.
        :param PolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 document: Optional[pulumi.Input[builtins.str]] = None,
                 force: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 policy_document: Optional[pulumi.Input[builtins.str]] = None,
                 policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 rotate_strategy: Optional[pulumi.Input[builtins.str]] = None,
                 statements: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicyStatementArgs', 'PolicyStatementArgsDict']]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 version: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PolicyArgs.__new__(PolicyArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["document"] = document
            __props__.__dict__["force"] = force
            __props__.__dict__["name"] = name
            __props__.__dict__["policy_document"] = policy_document
            __props__.__dict__["policy_name"] = policy_name
            __props__.__dict__["rotate_strategy"] = rotate_strategy
            __props__.__dict__["statements"] = statements
            __props__.__dict__["tags"] = tags
            __props__.__dict__["version"] = version
            __props__.__dict__["attachment_count"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["default_version"] = None
            __props__.__dict__["type"] = None
            __props__.__dict__["version_id"] = None
        super(Policy, __self__).__init__(
            'alicloud:ram/policy:Policy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            attachment_count: Optional[pulumi.Input[builtins.int]] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            default_version: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            document: Optional[pulumi.Input[builtins.str]] = None,
            force: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            policy_document: Optional[pulumi.Input[builtins.str]] = None,
            policy_name: Optional[pulumi.Input[builtins.str]] = None,
            rotate_strategy: Optional[pulumi.Input[builtins.str]] = None,
            statements: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PolicyStatementArgs', 'PolicyStatementArgsDict']]]]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            version: Optional[pulumi.Input[builtins.str]] = None,
            version_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Policy':
        """
        Get an existing Policy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] attachment_count: Number of attachments of the policy.
        :param pulumi.Input[builtins.str] create_time: (Available since v1.246.0) The create time of the policy.
        :param pulumi.Input[builtins.str] default_version: The default version ID of the policy.
        :param pulumi.Input[builtins.str] description: The description of the policy. It can be 1 to 1024 characters in length.
        :param pulumi.Input[builtins.str] document: Field `document` has been deprecated from provider version 1.114.0. New field `policy_document` instead.
        :param pulumi.Input[builtins.bool] force: Specifies whether to force delete the Policy. Default value: `false`. Valid values:
        :param pulumi.Input[builtins.str] name: Field `name` has been deprecated from provider version 1.114.0. New field `policy_name` instead.
        :param pulumi.Input[builtins.str] policy_document: The content of the policy. The maximum length is 6144 bytes.
        :param pulumi.Input[builtins.str] policy_name: The policy name. It can be 1 to 128 characters in length and can contain English letters, digits, and dashes (-).
        :param pulumi.Input[builtins.str] rotate_strategy: The automatic rotation mechanism of policy versions can delete historical policy versions. The default value is None. Valid values:
               - `None`: Turn off the rotation mechanism.
               - `DeleteOldestNonDefaultVersionWhenLimitExceeded`: When the number of permission policy versions exceeds the limit, the oldest and inactive version is deleted.
        :param pulumi.Input[Sequence[pulumi.Input[Union['PolicyStatementArgs', 'PolicyStatementArgsDict']]]] statements: Field `statement` has been deprecated from provider version 1.49.0. New field `document` instead. See `statement` below.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: The list of tags on the policy.
        :param pulumi.Input[builtins.str] type: The type of the policy.
        :param pulumi.Input[builtins.str] version: Field `version` has been deprecated from provider version 1.49.0. New field `document` instead.
        :param pulumi.Input[builtins.str] version_id: The ID of the default policy version.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PolicyState.__new__(_PolicyState)

        __props__.__dict__["attachment_count"] = attachment_count
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["default_version"] = default_version
        __props__.__dict__["description"] = description
        __props__.__dict__["document"] = document
        __props__.__dict__["force"] = force
        __props__.__dict__["name"] = name
        __props__.__dict__["policy_document"] = policy_document
        __props__.__dict__["policy_name"] = policy_name
        __props__.__dict__["rotate_strategy"] = rotate_strategy
        __props__.__dict__["statements"] = statements
        __props__.__dict__["tags"] = tags
        __props__.__dict__["type"] = type
        __props__.__dict__["version"] = version
        __props__.__dict__["version_id"] = version_id
        return Policy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="attachmentCount")
    def attachment_count(self) -> pulumi.Output[builtins.int]:
        """
        Number of attachments of the policy.
        """
        return pulumi.get(self, "attachment_count")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        (Available since v1.246.0) The create time of the policy.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="defaultVersion")
    def default_version(self) -> pulumi.Output[builtins.str]:
        """
        The default version ID of the policy.
        """
        return pulumi.get(self, "default_version")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The description of the policy. It can be 1 to 1024 characters in length.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'document' has been deprecated from provider version 1.114.0. New field 'policy_document' instead.""")
    def document(self) -> pulumi.Output[builtins.str]:
        """
        Field `document` has been deprecated from provider version 1.114.0. New field `policy_document` instead.
        """
        return pulumi.get(self, "document")

    @property
    @pulumi.getter
    def force(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether to force delete the Policy. Default value: `false`. Valid values:
        """
        return pulumi.get(self, "force")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'name' has been deprecated from provider version 1.114.0. New field 'policy_name' instead.""")
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Field `name` has been deprecated from provider version 1.114.0. New field `policy_name` instead.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="policyDocument")
    def policy_document(self) -> pulumi.Output[builtins.str]:
        """
        The content of the policy. The maximum length is 6144 bytes.
        """
        return pulumi.get(self, "policy_document")

    @property
    @pulumi.getter(name="policyName")
    def policy_name(self) -> pulumi.Output[builtins.str]:
        """
        The policy name. It can be 1 to 128 characters in length and can contain English letters, digits, and dashes (-).
        """
        return pulumi.get(self, "policy_name")

    @property
    @pulumi.getter(name="rotateStrategy")
    def rotate_strategy(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The automatic rotation mechanism of policy versions can delete historical policy versions. The default value is None. Valid values:
        - `None`: Turn off the rotation mechanism.
        - `DeleteOldestNonDefaultVersionWhenLimitExceeded`: When the number of permission policy versions exceeds the limit, the oldest and inactive version is deleted.
        """
        return pulumi.get(self, "rotate_strategy")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'statement' has been deprecated from version 1.49.0, and use field 'document' to replace. """)
    def statements(self) -> pulumi.Output[Sequence['outputs.PolicyStatement']]:
        """
        Field `statement` has been deprecated from provider version 1.49.0. New field `document` instead. See `statement` below.
        """
        return pulumi.get(self, "statements")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        The list of tags on the policy.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the policy.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Field 'version' has been deprecated from version 1.49.0, and use field 'document' to replace. """)
    def version(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Field `version` has been deprecated from provider version 1.49.0. New field `document` instead.
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="versionId")
    def version_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the default policy version.
        """
        return pulumi.get(self, "version_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AlertRobotArgs', 'AlertRobot']

@pulumi.input_type
class AlertRobotArgs:
    def __init__(__self__, *,
                 alert_robot_name: pulumi.Input[builtins.str],
                 robot_addr: pulumi.Input[builtins.str],
                 robot_type: pulumi.Input[builtins.str],
                 daily_noc: Optional[pulumi.Input[builtins.bool]] = None,
                 daily_noc_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a AlertRobot resource.
        :param pulumi.Input[builtins.str] alert_robot_name: The name of the resource.
        :param pulumi.Input[builtins.str] robot_addr: The webhook url of the robot.
        :param pulumi.Input[builtins.str] robot_type: The type of the robot, Valid values: `wechat`, `dingding`, `feishu`.
        :param pulumi.Input[builtins.bool] daily_noc: Specifies whether the alert robot receives daily notifications. Valid values: `true`: receives daily notifications. `false`: does not receive daily notifications, default to `false`.
        :param pulumi.Input[builtins.str] daily_noc_time: The time of the daily notification.
        """
        pulumi.set(__self__, "alert_robot_name", alert_robot_name)
        pulumi.set(__self__, "robot_addr", robot_addr)
        pulumi.set(__self__, "robot_type", robot_type)
        if daily_noc is not None:
            pulumi.set(__self__, "daily_noc", daily_noc)
        if daily_noc_time is not None:
            pulumi.set(__self__, "daily_noc_time", daily_noc_time)

    @property
    @pulumi.getter(name="alertRobotName")
    def alert_robot_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "alert_robot_name")

    @alert_robot_name.setter
    def alert_robot_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "alert_robot_name", value)

    @property
    @pulumi.getter(name="robotAddr")
    def robot_addr(self) -> pulumi.Input[builtins.str]:
        """
        The webhook url of the robot.
        """
        return pulumi.get(self, "robot_addr")

    @robot_addr.setter
    def robot_addr(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "robot_addr", value)

    @property
    @pulumi.getter(name="robotType")
    def robot_type(self) -> pulumi.Input[builtins.str]:
        """
        The type of the robot, Valid values: `wechat`, `dingding`, `feishu`.
        """
        return pulumi.get(self, "robot_type")

    @robot_type.setter
    def robot_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "robot_type", value)

    @property
    @pulumi.getter(name="dailyNoc")
    def daily_noc(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the alert robot receives daily notifications. Valid values: `true`: receives daily notifications. `false`: does not receive daily notifications, default to `false`.
        """
        return pulumi.get(self, "daily_noc")

    @daily_noc.setter
    def daily_noc(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "daily_noc", value)

    @property
    @pulumi.getter(name="dailyNocTime")
    def daily_noc_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time of the daily notification.
        """
        return pulumi.get(self, "daily_noc_time")

    @daily_noc_time.setter
    def daily_noc_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "daily_noc_time", value)


@pulumi.input_type
class _AlertRobotState:
    def __init__(__self__, *,
                 alert_robot_name: Optional[pulumi.Input[builtins.str]] = None,
                 daily_noc: Optional[pulumi.Input[builtins.bool]] = None,
                 daily_noc_time: Optional[pulumi.Input[builtins.str]] = None,
                 robot_addr: Optional[pulumi.Input[builtins.str]] = None,
                 robot_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering AlertRobot resources.
        :param pulumi.Input[builtins.str] alert_robot_name: The name of the resource.
        :param pulumi.Input[builtins.bool] daily_noc: Specifies whether the alert robot receives daily notifications. Valid values: `true`: receives daily notifications. `false`: does not receive daily notifications, default to `false`.
        :param pulumi.Input[builtins.str] daily_noc_time: The time of the daily notification.
        :param pulumi.Input[builtins.str] robot_addr: The webhook url of the robot.
        :param pulumi.Input[builtins.str] robot_type: The type of the robot, Valid values: `wechat`, `dingding`, `feishu`.
        """
        if alert_robot_name is not None:
            pulumi.set(__self__, "alert_robot_name", alert_robot_name)
        if daily_noc is not None:
            pulumi.set(__self__, "daily_noc", daily_noc)
        if daily_noc_time is not None:
            pulumi.set(__self__, "daily_noc_time", daily_noc_time)
        if robot_addr is not None:
            pulumi.set(__self__, "robot_addr", robot_addr)
        if robot_type is not None:
            pulumi.set(__self__, "robot_type", robot_type)

    @property
    @pulumi.getter(name="alertRobotName")
    def alert_robot_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "alert_robot_name")

    @alert_robot_name.setter
    def alert_robot_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "alert_robot_name", value)

    @property
    @pulumi.getter(name="dailyNoc")
    def daily_noc(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Specifies whether the alert robot receives daily notifications. Valid values: `true`: receives daily notifications. `false`: does not receive daily notifications, default to `false`.
        """
        return pulumi.get(self, "daily_noc")

    @daily_noc.setter
    def daily_noc(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "daily_noc", value)

    @property
    @pulumi.getter(name="dailyNocTime")
    def daily_noc_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time of the daily notification.
        """
        return pulumi.get(self, "daily_noc_time")

    @daily_noc_time.setter
    def daily_noc_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "daily_noc_time", value)

    @property
    @pulumi.getter(name="robotAddr")
    def robot_addr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The webhook url of the robot.
        """
        return pulumi.get(self, "robot_addr")

    @robot_addr.setter
    def robot_addr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "robot_addr", value)

    @property
    @pulumi.getter(name="robotType")
    def robot_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of the robot, Valid values: `wechat`, `dingding`, `feishu`.
        """
        return pulumi.get(self, "robot_type")

    @robot_type.setter
    def robot_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "robot_type", value)


@pulumi.type_token("alicloud:arms/alertRobot:AlertRobot")
class AlertRobot(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_robot_name: Optional[pulumi.Input[builtins.str]] = None,
                 daily_noc: Optional[pulumi.Input[builtins.bool]] = None,
                 daily_noc_time: Optional[pulumi.Input[builtins.str]] = None,
                 robot_addr: Optional[pulumi.Input[builtins.str]] = None,
                 robot_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Application Real-Time Monitoring Service (ARMS) Alert Robot resource.

        For information about Application Real-Time Monitoring Service (ARMS) Alert Robot and how to use it, see [What is Alert Robot](https://next.api.alibabacloud.com/document/ARMS/2019-08-08/CreateOrUpdateIMRobot).

        > **NOTE:** Available since v1.237.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        wechat = alicloud.arms.AlertRobot("wechat",
            alert_robot_name="example_wechat",
            robot_type="wechat",
            robot_addr="https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=1c704e23",
            daily_noc=True,
            daily_noc_time="09:30,17:00")
        dingding = alicloud.arms.AlertRobot("dingding",
            alert_robot_name="example_dingding",
            robot_type="dingding",
            robot_addr="https://oapi.dingtalk.com/robot/send?access_token=1c704e23",
            daily_noc=True,
            daily_noc_time="09:30,17:00")
        feishu = alicloud.arms.AlertRobot("feishu",
            alert_robot_name="example_feishu",
            robot_type="feishu",
            robot_addr="https://open.feishu.cn/open-apis/bot/v2/hook/a48efa01",
            daily_noc=True,
            daily_noc_time="09:30,17:00")
        ```

        ## Import

        Application Real-Time Monitoring Service (ARMS) Alert Robot can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:arms/alertRobot:AlertRobot example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] alert_robot_name: The name of the resource.
        :param pulumi.Input[builtins.bool] daily_noc: Specifies whether the alert robot receives daily notifications. Valid values: `true`: receives daily notifications. `false`: does not receive daily notifications, default to `false`.
        :param pulumi.Input[builtins.str] daily_noc_time: The time of the daily notification.
        :param pulumi.Input[builtins.str] robot_addr: The webhook url of the robot.
        :param pulumi.Input[builtins.str] robot_type: The type of the robot, Valid values: `wechat`, `dingding`, `feishu`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AlertRobotArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Application Real-Time Monitoring Service (ARMS) Alert Robot resource.

        For information about Application Real-Time Monitoring Service (ARMS) Alert Robot and how to use it, see [What is Alert Robot](https://next.api.alibabacloud.com/document/ARMS/2019-08-08/CreateOrUpdateIMRobot).

        > **NOTE:** Available since v1.237.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        wechat = alicloud.arms.AlertRobot("wechat",
            alert_robot_name="example_wechat",
            robot_type="wechat",
            robot_addr="https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key=1c704e23",
            daily_noc=True,
            daily_noc_time="09:30,17:00")
        dingding = alicloud.arms.AlertRobot("dingding",
            alert_robot_name="example_dingding",
            robot_type="dingding",
            robot_addr="https://oapi.dingtalk.com/robot/send?access_token=1c704e23",
            daily_noc=True,
            daily_noc_time="09:30,17:00")
        feishu = alicloud.arms.AlertRobot("feishu",
            alert_robot_name="example_feishu",
            robot_type="feishu",
            robot_addr="https://open.feishu.cn/open-apis/bot/v2/hook/a48efa01",
            daily_noc=True,
            daily_noc_time="09:30,17:00")
        ```

        ## Import

        Application Real-Time Monitoring Service (ARMS) Alert Robot can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:arms/alertRobot:AlertRobot example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AlertRobotArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AlertRobotArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 alert_robot_name: Optional[pulumi.Input[builtins.str]] = None,
                 daily_noc: Optional[pulumi.Input[builtins.bool]] = None,
                 daily_noc_time: Optional[pulumi.Input[builtins.str]] = None,
                 robot_addr: Optional[pulumi.Input[builtins.str]] = None,
                 robot_type: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AlertRobotArgs.__new__(AlertRobotArgs)

            if alert_robot_name is None and not opts.urn:
                raise TypeError("Missing required property 'alert_robot_name'")
            __props__.__dict__["alert_robot_name"] = alert_robot_name
            __props__.__dict__["daily_noc"] = daily_noc
            __props__.__dict__["daily_noc_time"] = daily_noc_time
            if robot_addr is None and not opts.urn:
                raise TypeError("Missing required property 'robot_addr'")
            __props__.__dict__["robot_addr"] = robot_addr
            if robot_type is None and not opts.urn:
                raise TypeError("Missing required property 'robot_type'")
            __props__.__dict__["robot_type"] = robot_type
        super(AlertRobot, __self__).__init__(
            'alicloud:arms/alertRobot:AlertRobot',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            alert_robot_name: Optional[pulumi.Input[builtins.str]] = None,
            daily_noc: Optional[pulumi.Input[builtins.bool]] = None,
            daily_noc_time: Optional[pulumi.Input[builtins.str]] = None,
            robot_addr: Optional[pulumi.Input[builtins.str]] = None,
            robot_type: Optional[pulumi.Input[builtins.str]] = None) -> 'AlertRobot':
        """
        Get an existing AlertRobot resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] alert_robot_name: The name of the resource.
        :param pulumi.Input[builtins.bool] daily_noc: Specifies whether the alert robot receives daily notifications. Valid values: `true`: receives daily notifications. `false`: does not receive daily notifications, default to `false`.
        :param pulumi.Input[builtins.str] daily_noc_time: The time of the daily notification.
        :param pulumi.Input[builtins.str] robot_addr: The webhook url of the robot.
        :param pulumi.Input[builtins.str] robot_type: The type of the robot, Valid values: `wechat`, `dingding`, `feishu`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AlertRobotState.__new__(_AlertRobotState)

        __props__.__dict__["alert_robot_name"] = alert_robot_name
        __props__.__dict__["daily_noc"] = daily_noc
        __props__.__dict__["daily_noc_time"] = daily_noc_time
        __props__.__dict__["robot_addr"] = robot_addr
        __props__.__dict__["robot_type"] = robot_type
        return AlertRobot(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="alertRobotName")
    def alert_robot_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the resource.
        """
        return pulumi.get(self, "alert_robot_name")

    @property
    @pulumi.getter(name="dailyNoc")
    def daily_noc(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Specifies whether the alert robot receives daily notifications. Valid values: `true`: receives daily notifications. `false`: does not receive daily notifications, default to `false`.
        """
        return pulumi.get(self, "daily_noc")

    @property
    @pulumi.getter(name="dailyNocTime")
    def daily_noc_time(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The time of the daily notification.
        """
        return pulumi.get(self, "daily_noc_time")

    @property
    @pulumi.getter(name="robotAddr")
    def robot_addr(self) -> pulumi.Output[builtins.str]:
        """
        The webhook url of the robot.
        """
        return pulumi.get(self, "robot_addr")

    @property
    @pulumi.getter(name="robotType")
    def robot_type(self) -> pulumi.Output[builtins.str]:
        """
        The type of the robot, Valid values: `wechat`, `dingding`, `feishu`.
        """
        return pulumi.get(self, "robot_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetShardingNetworkPublicAddressesResult',
    'AwaitableGetShardingNetworkPublicAddressesResult',
    'get_sharding_network_public_addresses',
    'get_sharding_network_public_addresses_output',
]

@pulumi.output_type
class GetShardingNetworkPublicAddressesResult:
    """
    A collection of values returned by getShardingNetworkPublicAddresses.
    """
    def __init__(__self__, addresses=None, db_instance_id=None, id=None, node_id=None, output_file=None, role=None):
        if addresses and not isinstance(addresses, list):
            raise TypeError("Expected argument 'addresses' to be a list")
        pulumi.set(__self__, "addresses", addresses)
        if db_instance_id and not isinstance(db_instance_id, str):
            raise TypeError("Expected argument 'db_instance_id' to be a str")
        pulumi.set(__self__, "db_instance_id", db_instance_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if node_id and not isinstance(node_id, str):
            raise TypeError("Expected argument 'node_id' to be a str")
        pulumi.set(__self__, "node_id", node_id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if role and not isinstance(role, str):
            raise TypeError("Expected argument 'role' to be a str")
        pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter
    def addresses(self) -> Sequence['outputs.GetShardingNetworkPublicAddressesAddressResult']:
        return pulumi.get(self, "addresses")

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> builtins.str:
        return pulumi.get(self, "db_instance_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def role(self) -> Optional[builtins.str]:
        return pulumi.get(self, "role")


class AwaitableGetShardingNetworkPublicAddressesResult(GetShardingNetworkPublicAddressesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetShardingNetworkPublicAddressesResult(
            addresses=self.addresses,
            db_instance_id=self.db_instance_id,
            id=self.id,
            node_id=self.node_id,
            output_file=self.output_file,
            role=self.role)


def get_sharding_network_public_addresses(db_instance_id: Optional[builtins.str] = None,
                                          node_id: Optional[builtins.str] = None,
                                          output_file: Optional[builtins.str] = None,
                                          role: Optional[builtins.str] = None,
                                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetShardingNetworkPublicAddressesResult:
    """
    This data source provides the Mongodb Sharding Network Public Addresses of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.149.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.mongodb.get_sharding_network_public_addresses(db_instance_id="example_value",
        node_id="example_value",
        role="Primary")
    pulumi.export("mongodbShardingNetworkPublicAddressDbInstanceId1", example.addresses[0].db_instance_id)
    ```


    :param builtins.str db_instance_id: The db instance id.
    :param builtins.str node_id: The ID of the `mongos`, `shard`, or `Configserver` node in the sharded cluster instance.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str role: The role of the node. Valid values: `Primary` or `Secondary`.
    """
    __args__ = dict()
    __args__['dbInstanceId'] = db_instance_id
    __args__['nodeId'] = node_id
    __args__['outputFile'] = output_file
    __args__['role'] = role
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:mongodb/getShardingNetworkPublicAddresses:getShardingNetworkPublicAddresses', __args__, opts=opts, typ=GetShardingNetworkPublicAddressesResult).value

    return AwaitableGetShardingNetworkPublicAddressesResult(
        addresses=pulumi.get(__ret__, 'addresses'),
        db_instance_id=pulumi.get(__ret__, 'db_instance_id'),
        id=pulumi.get(__ret__, 'id'),
        node_id=pulumi.get(__ret__, 'node_id'),
        output_file=pulumi.get(__ret__, 'output_file'),
        role=pulumi.get(__ret__, 'role'))
def get_sharding_network_public_addresses_output(db_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                                                 node_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                                 output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                                 role: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetShardingNetworkPublicAddressesResult]:
    """
    This data source provides the Mongodb Sharding Network Public Addresses of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.149.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.mongodb.get_sharding_network_public_addresses(db_instance_id="example_value",
        node_id="example_value",
        role="Primary")
    pulumi.export("mongodbShardingNetworkPublicAddressDbInstanceId1", example.addresses[0].db_instance_id)
    ```


    :param builtins.str db_instance_id: The db instance id.
    :param builtins.str node_id: The ID of the `mongos`, `shard`, or `Configserver` node in the sharded cluster instance.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str role: The role of the node. Valid values: `Primary` or `Secondary`.
    """
    __args__ = dict()
    __args__['dbInstanceId'] = db_instance_id
    __args__['nodeId'] = node_id
    __args__['outputFile'] = output_file
    __args__['role'] = role
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:mongodb/getShardingNetworkPublicAddresses:getShardingNetworkPublicAddresses', __args__, opts=opts, typ=GetShardingNetworkPublicAddressesResult)
    return __ret__.apply(lambda __response__: GetShardingNetworkPublicAddressesResult(
        addresses=pulumi.get(__response__, 'addresses'),
        db_instance_id=pulumi.get(__response__, 'db_instance_id'),
        id=pulumi.get(__response__, 'id'),
        node_id=pulumi.get(__response__, 'node_id'),
        output_file=pulumi.get(__response__, 'output_file'),
        role=pulumi.get(__response__, 'role')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SiteDeliveryTaskArgs', 'SiteDeliveryTask']

@pulumi.input_type
class SiteDeliveryTaskArgs:
    def __init__(__self__, *,
                 business_type: pulumi.Input[builtins.str],
                 data_center: pulumi.Input[builtins.str],
                 delivery_type: pulumi.Input[builtins.str],
                 field_name: pulumi.Input[builtins.str],
                 site_id: pulumi.Input[builtins.int],
                 task_name: pulumi.Input[builtins.str],
                 discard_rate: Optional[pulumi.Input[builtins.float]] = None,
                 http_delivery: Optional[pulumi.Input['SiteDeliveryTaskHttpDeliveryArgs']] = None,
                 kafka_delivery: Optional[pulumi.Input['SiteDeliveryTaskKafkaDeliveryArgs']] = None,
                 oss_delivery: Optional[pulumi.Input['SiteDeliveryTaskOssDeliveryArgs']] = None,
                 s3_delivery: Optional[pulumi.Input['SiteDeliveryTaskS3DeliveryArgs']] = None,
                 sls_delivery: Optional[pulumi.Input['SiteDeliveryTaskSlsDeliveryArgs']] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a SiteDeliveryTask resource.
        :param pulumi.Input[builtins.str] business_type: Real-time log type. Valid values:
               - `dcdn_log_access_l1 (default)`: access log.
        :param pulumi.Input[builtins.str] data_center: Data Center. Values:
        :param pulumi.Input[builtins.str] delivery_type: Delivery Type:
        :param pulumi.Input[builtins.str] field_name: The list of delivery fields to be modified, separated by commas.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        :param pulumi.Input[builtins.str] task_name: The task name.
        :param pulumi.Input[builtins.float] discard_rate: If the discard rate is not filled, the default value is 0.
        :param pulumi.Input['SiteDeliveryTaskHttpDeliveryArgs'] http_delivery: HTTP delivery configuration parameters. See `http_delivery` below.
        :param pulumi.Input['SiteDeliveryTaskKafkaDeliveryArgs'] kafka_delivery: Kafka delivery configuration parameters. See `kafka_delivery` below.
        :param pulumi.Input['SiteDeliveryTaskOssDeliveryArgs'] oss_delivery: OSS delivery configuration. See `oss_delivery` below.
        :param pulumi.Input['SiteDeliveryTaskS3DeliveryArgs'] s3_delivery: S3/S3 compatible delivery configuration parameters. See `s3_delivery` below.
        :param pulumi.Input['SiteDeliveryTaskSlsDeliveryArgs'] sls_delivery: SLS delivery configuration. See `sls_delivery` below.
        :param pulumi.Input[builtins.str] status: Task status, value:
        """
        pulumi.set(__self__, "business_type", business_type)
        pulumi.set(__self__, "data_center", data_center)
        pulumi.set(__self__, "delivery_type", delivery_type)
        pulumi.set(__self__, "field_name", field_name)
        pulumi.set(__self__, "site_id", site_id)
        pulumi.set(__self__, "task_name", task_name)
        if discard_rate is not None:
            pulumi.set(__self__, "discard_rate", discard_rate)
        if http_delivery is not None:
            pulumi.set(__self__, "http_delivery", http_delivery)
        if kafka_delivery is not None:
            pulumi.set(__self__, "kafka_delivery", kafka_delivery)
        if oss_delivery is not None:
            pulumi.set(__self__, "oss_delivery", oss_delivery)
        if s3_delivery is not None:
            pulumi.set(__self__, "s3_delivery", s3_delivery)
        if sls_delivery is not None:
            pulumi.set(__self__, "sls_delivery", sls_delivery)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="businessType")
    def business_type(self) -> pulumi.Input[builtins.str]:
        """
        Real-time log type. Valid values:
        - `dcdn_log_access_l1 (default)`: access log.
        """
        return pulumi.get(self, "business_type")

    @business_type.setter
    def business_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "business_type", value)

    @property
    @pulumi.getter(name="dataCenter")
    def data_center(self) -> pulumi.Input[builtins.str]:
        """
        Data Center. Values:
        """
        return pulumi.get(self, "data_center")

    @data_center.setter
    def data_center(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "data_center", value)

    @property
    @pulumi.getter(name="deliveryType")
    def delivery_type(self) -> pulumi.Input[builtins.str]:
        """
        Delivery Type:
        """
        return pulumi.get(self, "delivery_type")

    @delivery_type.setter
    def delivery_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "delivery_type", value)

    @property
    @pulumi.getter(name="fieldName")
    def field_name(self) -> pulumi.Input[builtins.str]:
        """
        The list of delivery fields to be modified, separated by commas.
        """
        return pulumi.get(self, "field_name")

    @field_name.setter
    def field_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "field_name", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="taskName")
    def task_name(self) -> pulumi.Input[builtins.str]:
        """
        The task name.
        """
        return pulumi.get(self, "task_name")

    @task_name.setter
    def task_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "task_name", value)

    @property
    @pulumi.getter(name="discardRate")
    def discard_rate(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        If the discard rate is not filled, the default value is 0.
        """
        return pulumi.get(self, "discard_rate")

    @discard_rate.setter
    def discard_rate(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "discard_rate", value)

    @property
    @pulumi.getter(name="httpDelivery")
    def http_delivery(self) -> Optional[pulumi.Input['SiteDeliveryTaskHttpDeliveryArgs']]:
        """
        HTTP delivery configuration parameters. See `http_delivery` below.
        """
        return pulumi.get(self, "http_delivery")

    @http_delivery.setter
    def http_delivery(self, value: Optional[pulumi.Input['SiteDeliveryTaskHttpDeliveryArgs']]):
        pulumi.set(self, "http_delivery", value)

    @property
    @pulumi.getter(name="kafkaDelivery")
    def kafka_delivery(self) -> Optional[pulumi.Input['SiteDeliveryTaskKafkaDeliveryArgs']]:
        """
        Kafka delivery configuration parameters. See `kafka_delivery` below.
        """
        return pulumi.get(self, "kafka_delivery")

    @kafka_delivery.setter
    def kafka_delivery(self, value: Optional[pulumi.Input['SiteDeliveryTaskKafkaDeliveryArgs']]):
        pulumi.set(self, "kafka_delivery", value)

    @property
    @pulumi.getter(name="ossDelivery")
    def oss_delivery(self) -> Optional[pulumi.Input['SiteDeliveryTaskOssDeliveryArgs']]:
        """
        OSS delivery configuration. See `oss_delivery` below.
        """
        return pulumi.get(self, "oss_delivery")

    @oss_delivery.setter
    def oss_delivery(self, value: Optional[pulumi.Input['SiteDeliveryTaskOssDeliveryArgs']]):
        pulumi.set(self, "oss_delivery", value)

    @property
    @pulumi.getter(name="s3Delivery")
    def s3_delivery(self) -> Optional[pulumi.Input['SiteDeliveryTaskS3DeliveryArgs']]:
        """
        S3/S3 compatible delivery configuration parameters. See `s3_delivery` below.
        """
        return pulumi.get(self, "s3_delivery")

    @s3_delivery.setter
    def s3_delivery(self, value: Optional[pulumi.Input['SiteDeliveryTaskS3DeliveryArgs']]):
        pulumi.set(self, "s3_delivery", value)

    @property
    @pulumi.getter(name="slsDelivery")
    def sls_delivery(self) -> Optional[pulumi.Input['SiteDeliveryTaskSlsDeliveryArgs']]:
        """
        SLS delivery configuration. See `sls_delivery` below.
        """
        return pulumi.get(self, "sls_delivery")

    @sls_delivery.setter
    def sls_delivery(self, value: Optional[pulumi.Input['SiteDeliveryTaskSlsDeliveryArgs']]):
        pulumi.set(self, "sls_delivery", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task status, value:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _SiteDeliveryTaskState:
    def __init__(__self__, *,
                 business_type: Optional[pulumi.Input[builtins.str]] = None,
                 data_center: Optional[pulumi.Input[builtins.str]] = None,
                 delivery_type: Optional[pulumi.Input[builtins.str]] = None,
                 discard_rate: Optional[pulumi.Input[builtins.float]] = None,
                 field_name: Optional[pulumi.Input[builtins.str]] = None,
                 http_delivery: Optional[pulumi.Input['SiteDeliveryTaskHttpDeliveryArgs']] = None,
                 kafka_delivery: Optional[pulumi.Input['SiteDeliveryTaskKafkaDeliveryArgs']] = None,
                 oss_delivery: Optional[pulumi.Input['SiteDeliveryTaskOssDeliveryArgs']] = None,
                 s3_delivery: Optional[pulumi.Input['SiteDeliveryTaskS3DeliveryArgs']] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 sls_delivery: Optional[pulumi.Input['SiteDeliveryTaskSlsDeliveryArgs']] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 task_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering SiteDeliveryTask resources.
        :param pulumi.Input[builtins.str] business_type: Real-time log type. Valid values:
               - `dcdn_log_access_l1 (default)`: access log.
        :param pulumi.Input[builtins.str] data_center: Data Center. Values:
        :param pulumi.Input[builtins.str] delivery_type: Delivery Type:
        :param pulumi.Input[builtins.float] discard_rate: If the discard rate is not filled, the default value is 0.
        :param pulumi.Input[builtins.str] field_name: The list of delivery fields to be modified, separated by commas.
        :param pulumi.Input['SiteDeliveryTaskHttpDeliveryArgs'] http_delivery: HTTP delivery configuration parameters. See `http_delivery` below.
        :param pulumi.Input['SiteDeliveryTaskKafkaDeliveryArgs'] kafka_delivery: Kafka delivery configuration parameters. See `kafka_delivery` below.
        :param pulumi.Input['SiteDeliveryTaskOssDeliveryArgs'] oss_delivery: OSS delivery configuration. See `oss_delivery` below.
        :param pulumi.Input['SiteDeliveryTaskS3DeliveryArgs'] s3_delivery: S3/S3 compatible delivery configuration parameters. See `s3_delivery` below.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        :param pulumi.Input['SiteDeliveryTaskSlsDeliveryArgs'] sls_delivery: SLS delivery configuration. See `sls_delivery` below.
        :param pulumi.Input[builtins.str] status: Task status, value:
        :param pulumi.Input[builtins.str] task_name: The task name.
        """
        if business_type is not None:
            pulumi.set(__self__, "business_type", business_type)
        if data_center is not None:
            pulumi.set(__self__, "data_center", data_center)
        if delivery_type is not None:
            pulumi.set(__self__, "delivery_type", delivery_type)
        if discard_rate is not None:
            pulumi.set(__self__, "discard_rate", discard_rate)
        if field_name is not None:
            pulumi.set(__self__, "field_name", field_name)
        if http_delivery is not None:
            pulumi.set(__self__, "http_delivery", http_delivery)
        if kafka_delivery is not None:
            pulumi.set(__self__, "kafka_delivery", kafka_delivery)
        if oss_delivery is not None:
            pulumi.set(__self__, "oss_delivery", oss_delivery)
        if s3_delivery is not None:
            pulumi.set(__self__, "s3_delivery", s3_delivery)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if sls_delivery is not None:
            pulumi.set(__self__, "sls_delivery", sls_delivery)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if task_name is not None:
            pulumi.set(__self__, "task_name", task_name)

    @property
    @pulumi.getter(name="businessType")
    def business_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Real-time log type. Valid values:
        - `dcdn_log_access_l1 (default)`: access log.
        """
        return pulumi.get(self, "business_type")

    @business_type.setter
    def business_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_type", value)

    @property
    @pulumi.getter(name="dataCenter")
    def data_center(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Data Center. Values:
        """
        return pulumi.get(self, "data_center")

    @data_center.setter
    def data_center(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "data_center", value)

    @property
    @pulumi.getter(name="deliveryType")
    def delivery_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Delivery Type:
        """
        return pulumi.get(self, "delivery_type")

    @delivery_type.setter
    def delivery_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "delivery_type", value)

    @property
    @pulumi.getter(name="discardRate")
    def discard_rate(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        If the discard rate is not filled, the default value is 0.
        """
        return pulumi.get(self, "discard_rate")

    @discard_rate.setter
    def discard_rate(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "discard_rate", value)

    @property
    @pulumi.getter(name="fieldName")
    def field_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The list of delivery fields to be modified, separated by commas.
        """
        return pulumi.get(self, "field_name")

    @field_name.setter
    def field_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "field_name", value)

    @property
    @pulumi.getter(name="httpDelivery")
    def http_delivery(self) -> Optional[pulumi.Input['SiteDeliveryTaskHttpDeliveryArgs']]:
        """
        HTTP delivery configuration parameters. See `http_delivery` below.
        """
        return pulumi.get(self, "http_delivery")

    @http_delivery.setter
    def http_delivery(self, value: Optional[pulumi.Input['SiteDeliveryTaskHttpDeliveryArgs']]):
        pulumi.set(self, "http_delivery", value)

    @property
    @pulumi.getter(name="kafkaDelivery")
    def kafka_delivery(self) -> Optional[pulumi.Input['SiteDeliveryTaskKafkaDeliveryArgs']]:
        """
        Kafka delivery configuration parameters. See `kafka_delivery` below.
        """
        return pulumi.get(self, "kafka_delivery")

    @kafka_delivery.setter
    def kafka_delivery(self, value: Optional[pulumi.Input['SiteDeliveryTaskKafkaDeliveryArgs']]):
        pulumi.set(self, "kafka_delivery", value)

    @property
    @pulumi.getter(name="ossDelivery")
    def oss_delivery(self) -> Optional[pulumi.Input['SiteDeliveryTaskOssDeliveryArgs']]:
        """
        OSS delivery configuration. See `oss_delivery` below.
        """
        return pulumi.get(self, "oss_delivery")

    @oss_delivery.setter
    def oss_delivery(self, value: Optional[pulumi.Input['SiteDeliveryTaskOssDeliveryArgs']]):
        pulumi.set(self, "oss_delivery", value)

    @property
    @pulumi.getter(name="s3Delivery")
    def s3_delivery(self) -> Optional[pulumi.Input['SiteDeliveryTaskS3DeliveryArgs']]:
        """
        S3/S3 compatible delivery configuration parameters. See `s3_delivery` below.
        """
        return pulumi.get(self, "s3_delivery")

    @s3_delivery.setter
    def s3_delivery(self, value: Optional[pulumi.Input['SiteDeliveryTaskS3DeliveryArgs']]):
        pulumi.set(self, "s3_delivery", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="slsDelivery")
    def sls_delivery(self) -> Optional[pulumi.Input['SiteDeliveryTaskSlsDeliveryArgs']]:
        """
        SLS delivery configuration. See `sls_delivery` below.
        """
        return pulumi.get(self, "sls_delivery")

    @sls_delivery.setter
    def sls_delivery(self, value: Optional[pulumi.Input['SiteDeliveryTaskSlsDeliveryArgs']]):
        pulumi.set(self, "sls_delivery", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task status, value:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="taskName")
    def task_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The task name.
        """
        return pulumi.get(self, "task_name")

    @task_name.setter
    def task_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "task_name", value)


@pulumi.type_token("alicloud:esa/siteDeliveryTask:SiteDeliveryTask")
class SiteDeliveryTask(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 business_type: Optional[pulumi.Input[builtins.str]] = None,
                 data_center: Optional[pulumi.Input[builtins.str]] = None,
                 delivery_type: Optional[pulumi.Input[builtins.str]] = None,
                 discard_rate: Optional[pulumi.Input[builtins.float]] = None,
                 field_name: Optional[pulumi.Input[builtins.str]] = None,
                 http_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskHttpDeliveryArgs', 'SiteDeliveryTaskHttpDeliveryArgsDict']]] = None,
                 kafka_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskKafkaDeliveryArgs', 'SiteDeliveryTaskKafkaDeliveryArgsDict']]] = None,
                 oss_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskOssDeliveryArgs', 'SiteDeliveryTaskOssDeliveryArgsDict']]] = None,
                 s3_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskS3DeliveryArgs', 'SiteDeliveryTaskS3DeliveryArgsDict']]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 sls_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskSlsDeliveryArgs', 'SiteDeliveryTaskSlsDeliveryArgsDict']]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 task_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Site Delivery Task resource.

        For information about ESA Site Delivery Task and how to use it, see [What is Site Delivery Task](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateSiteDeliveryTask).

        > **NOTE:** Available since v1.247.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        resource_site_http_example = alicloud.esa.Site("resource_Site_http_example",
            site_name="chenxin0116.site",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_site_delivery_task = alicloud.esa.SiteDeliveryTask("default",
            http_delivery={
                "standard_auth_param": {
                    "private_key": "***",
                    "url_path": "v1/log/upload",
                    "expired_time": 300,
                },
                "transform_timeout": 10,
                "max_retry": 3,
                "max_batch_mb": 5,
                "compress": "gzip",
                "log_body_suffix": "cdnVersion:1.0",
                "standard_auth_on": False,
                "log_body_prefix": "cdnVersion:1.0",
                "dest_url": "http://11.177.129.13:8081",
                "max_batch_size": 1000,
            },
            data_center="oversea",
            discard_rate=0,
            task_name="dcdn-example-task",
            business_type="dcdn_log_access_l1",
            field_name="ConsoleLog,CPUTime,Duration,ErrorCode,ErrorMessage,ResponseSize,ResponseStatus,RoutineName,ClientRequestID,LogTimestamp,FetchStatus,SubRequestID",
            delivery_type="http",
            site_id=resource_site_http_example.id)
        ```

        ## Import

        ESA Site Delivery Task can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/siteDeliveryTask:SiteDeliveryTask example <site_id>:<task_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] business_type: Real-time log type. Valid values:
               - `dcdn_log_access_l1 (default)`: access log.
        :param pulumi.Input[builtins.str] data_center: Data Center. Values:
        :param pulumi.Input[builtins.str] delivery_type: Delivery Type:
        :param pulumi.Input[builtins.float] discard_rate: If the discard rate is not filled, the default value is 0.
        :param pulumi.Input[builtins.str] field_name: The list of delivery fields to be modified, separated by commas.
        :param pulumi.Input[Union['SiteDeliveryTaskHttpDeliveryArgs', 'SiteDeliveryTaskHttpDeliveryArgsDict']] http_delivery: HTTP delivery configuration parameters. See `http_delivery` below.
        :param pulumi.Input[Union['SiteDeliveryTaskKafkaDeliveryArgs', 'SiteDeliveryTaskKafkaDeliveryArgsDict']] kafka_delivery: Kafka delivery configuration parameters. See `kafka_delivery` below.
        :param pulumi.Input[Union['SiteDeliveryTaskOssDeliveryArgs', 'SiteDeliveryTaskOssDeliveryArgsDict']] oss_delivery: OSS delivery configuration. See `oss_delivery` below.
        :param pulumi.Input[Union['SiteDeliveryTaskS3DeliveryArgs', 'SiteDeliveryTaskS3DeliveryArgsDict']] s3_delivery: S3/S3 compatible delivery configuration parameters. See `s3_delivery` below.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        :param pulumi.Input[Union['SiteDeliveryTaskSlsDeliveryArgs', 'SiteDeliveryTaskSlsDeliveryArgsDict']] sls_delivery: SLS delivery configuration. See `sls_delivery` below.
        :param pulumi.Input[builtins.str] status: Task status, value:
        :param pulumi.Input[builtins.str] task_name: The task name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SiteDeliveryTaskArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Site Delivery Task resource.

        For information about ESA Site Delivery Task and how to use it, see [What is Site Delivery Task](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateSiteDeliveryTask).

        > **NOTE:** Available since v1.247.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        resource_site_http_example = alicloud.esa.Site("resource_Site_http_example",
            site_name="chenxin0116.site",
            instance_id=default.sites[0].instance_id,
            coverage="overseas",
            access_type="NS")
        default_site_delivery_task = alicloud.esa.SiteDeliveryTask("default",
            http_delivery={
                "standard_auth_param": {
                    "private_key": "***",
                    "url_path": "v1/log/upload",
                    "expired_time": 300,
                },
                "transform_timeout": 10,
                "max_retry": 3,
                "max_batch_mb": 5,
                "compress": "gzip",
                "log_body_suffix": "cdnVersion:1.0",
                "standard_auth_on": False,
                "log_body_prefix": "cdnVersion:1.0",
                "dest_url": "http://11.177.129.13:8081",
                "max_batch_size": 1000,
            },
            data_center="oversea",
            discard_rate=0,
            task_name="dcdn-example-task",
            business_type="dcdn_log_access_l1",
            field_name="ConsoleLog,CPUTime,Duration,ErrorCode,ErrorMessage,ResponseSize,ResponseStatus,RoutineName,ClientRequestID,LogTimestamp,FetchStatus,SubRequestID",
            delivery_type="http",
            site_id=resource_site_http_example.id)
        ```

        ## Import

        ESA Site Delivery Task can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/siteDeliveryTask:SiteDeliveryTask example <site_id>:<task_name>
        ```

        :param str resource_name: The name of the resource.
        :param SiteDeliveryTaskArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SiteDeliveryTaskArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 business_type: Optional[pulumi.Input[builtins.str]] = None,
                 data_center: Optional[pulumi.Input[builtins.str]] = None,
                 delivery_type: Optional[pulumi.Input[builtins.str]] = None,
                 discard_rate: Optional[pulumi.Input[builtins.float]] = None,
                 field_name: Optional[pulumi.Input[builtins.str]] = None,
                 http_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskHttpDeliveryArgs', 'SiteDeliveryTaskHttpDeliveryArgsDict']]] = None,
                 kafka_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskKafkaDeliveryArgs', 'SiteDeliveryTaskKafkaDeliveryArgsDict']]] = None,
                 oss_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskOssDeliveryArgs', 'SiteDeliveryTaskOssDeliveryArgsDict']]] = None,
                 s3_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskS3DeliveryArgs', 'SiteDeliveryTaskS3DeliveryArgsDict']]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 sls_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskSlsDeliveryArgs', 'SiteDeliveryTaskSlsDeliveryArgsDict']]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 task_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SiteDeliveryTaskArgs.__new__(SiteDeliveryTaskArgs)

            if business_type is None and not opts.urn:
                raise TypeError("Missing required property 'business_type'")
            __props__.__dict__["business_type"] = business_type
            if data_center is None and not opts.urn:
                raise TypeError("Missing required property 'data_center'")
            __props__.__dict__["data_center"] = data_center
            if delivery_type is None and not opts.urn:
                raise TypeError("Missing required property 'delivery_type'")
            __props__.__dict__["delivery_type"] = delivery_type
            __props__.__dict__["discard_rate"] = discard_rate
            if field_name is None and not opts.urn:
                raise TypeError("Missing required property 'field_name'")
            __props__.__dict__["field_name"] = field_name
            __props__.__dict__["http_delivery"] = http_delivery
            __props__.__dict__["kafka_delivery"] = kafka_delivery
            __props__.__dict__["oss_delivery"] = oss_delivery
            __props__.__dict__["s3_delivery"] = s3_delivery
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["sls_delivery"] = sls_delivery
            __props__.__dict__["status"] = status
            if task_name is None and not opts.urn:
                raise TypeError("Missing required property 'task_name'")
            __props__.__dict__["task_name"] = task_name
        super(SiteDeliveryTask, __self__).__init__(
            'alicloud:esa/siteDeliveryTask:SiteDeliveryTask',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            business_type: Optional[pulumi.Input[builtins.str]] = None,
            data_center: Optional[pulumi.Input[builtins.str]] = None,
            delivery_type: Optional[pulumi.Input[builtins.str]] = None,
            discard_rate: Optional[pulumi.Input[builtins.float]] = None,
            field_name: Optional[pulumi.Input[builtins.str]] = None,
            http_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskHttpDeliveryArgs', 'SiteDeliveryTaskHttpDeliveryArgsDict']]] = None,
            kafka_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskKafkaDeliveryArgs', 'SiteDeliveryTaskKafkaDeliveryArgsDict']]] = None,
            oss_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskOssDeliveryArgs', 'SiteDeliveryTaskOssDeliveryArgsDict']]] = None,
            s3_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskS3DeliveryArgs', 'SiteDeliveryTaskS3DeliveryArgsDict']]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            sls_delivery: Optional[pulumi.Input[Union['SiteDeliveryTaskSlsDeliveryArgs', 'SiteDeliveryTaskSlsDeliveryArgsDict']]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            task_name: Optional[pulumi.Input[builtins.str]] = None) -> 'SiteDeliveryTask':
        """
        Get an existing SiteDeliveryTask resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] business_type: Real-time log type. Valid values:
               - `dcdn_log_access_l1 (default)`: access log.
        :param pulumi.Input[builtins.str] data_center: Data Center. Values:
        :param pulumi.Input[builtins.str] delivery_type: Delivery Type:
        :param pulumi.Input[builtins.float] discard_rate: If the discard rate is not filled, the default value is 0.
        :param pulumi.Input[builtins.str] field_name: The list of delivery fields to be modified, separated by commas.
        :param pulumi.Input[Union['SiteDeliveryTaskHttpDeliveryArgs', 'SiteDeliveryTaskHttpDeliveryArgsDict']] http_delivery: HTTP delivery configuration parameters. See `http_delivery` below.
        :param pulumi.Input[Union['SiteDeliveryTaskKafkaDeliveryArgs', 'SiteDeliveryTaskKafkaDeliveryArgsDict']] kafka_delivery: Kafka delivery configuration parameters. See `kafka_delivery` below.
        :param pulumi.Input[Union['SiteDeliveryTaskOssDeliveryArgs', 'SiteDeliveryTaskOssDeliveryArgsDict']] oss_delivery: OSS delivery configuration. See `oss_delivery` below.
        :param pulumi.Input[Union['SiteDeliveryTaskS3DeliveryArgs', 'SiteDeliveryTaskS3DeliveryArgsDict']] s3_delivery: S3/S3 compatible delivery configuration parameters. See `s3_delivery` below.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        :param pulumi.Input[Union['SiteDeliveryTaskSlsDeliveryArgs', 'SiteDeliveryTaskSlsDeliveryArgsDict']] sls_delivery: SLS delivery configuration. See `sls_delivery` below.
        :param pulumi.Input[builtins.str] status: Task status, value:
        :param pulumi.Input[builtins.str] task_name: The task name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SiteDeliveryTaskState.__new__(_SiteDeliveryTaskState)

        __props__.__dict__["business_type"] = business_type
        __props__.__dict__["data_center"] = data_center
        __props__.__dict__["delivery_type"] = delivery_type
        __props__.__dict__["discard_rate"] = discard_rate
        __props__.__dict__["field_name"] = field_name
        __props__.__dict__["http_delivery"] = http_delivery
        __props__.__dict__["kafka_delivery"] = kafka_delivery
        __props__.__dict__["oss_delivery"] = oss_delivery
        __props__.__dict__["s3_delivery"] = s3_delivery
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["sls_delivery"] = sls_delivery
        __props__.__dict__["status"] = status
        __props__.__dict__["task_name"] = task_name
        return SiteDeliveryTask(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="businessType")
    def business_type(self) -> pulumi.Output[builtins.str]:
        """
        Real-time log type. Valid values:
        - `dcdn_log_access_l1 (default)`: access log.
        """
        return pulumi.get(self, "business_type")

    @property
    @pulumi.getter(name="dataCenter")
    def data_center(self) -> pulumi.Output[builtins.str]:
        """
        Data Center. Values:
        """
        return pulumi.get(self, "data_center")

    @property
    @pulumi.getter(name="deliveryType")
    def delivery_type(self) -> pulumi.Output[builtins.str]:
        """
        Delivery Type:
        """
        return pulumi.get(self, "delivery_type")

    @property
    @pulumi.getter(name="discardRate")
    def discard_rate(self) -> pulumi.Output[Optional[builtins.float]]:
        """
        If the discard rate is not filled, the default value is 0.
        """
        return pulumi.get(self, "discard_rate")

    @property
    @pulumi.getter(name="fieldName")
    def field_name(self) -> pulumi.Output[builtins.str]:
        """
        The list of delivery fields to be modified, separated by commas.
        """
        return pulumi.get(self, "field_name")

    @property
    @pulumi.getter(name="httpDelivery")
    def http_delivery(self) -> pulumi.Output[Optional['outputs.SiteDeliveryTaskHttpDelivery']]:
        """
        HTTP delivery configuration parameters. See `http_delivery` below.
        """
        return pulumi.get(self, "http_delivery")

    @property
    @pulumi.getter(name="kafkaDelivery")
    def kafka_delivery(self) -> pulumi.Output[Optional['outputs.SiteDeliveryTaskKafkaDelivery']]:
        """
        Kafka delivery configuration parameters. See `kafka_delivery` below.
        """
        return pulumi.get(self, "kafka_delivery")

    @property
    @pulumi.getter(name="ossDelivery")
    def oss_delivery(self) -> pulumi.Output[Optional['outputs.SiteDeliveryTaskOssDelivery']]:
        """
        OSS delivery configuration. See `oss_delivery` below.
        """
        return pulumi.get(self, "oss_delivery")

    @property
    @pulumi.getter(name="s3Delivery")
    def s3_delivery(self) -> pulumi.Output[Optional['outputs.SiteDeliveryTaskS3Delivery']]:
        """
        S3/S3 compatible delivery configuration parameters. See `s3_delivery` below.
        """
        return pulumi.get(self, "s3_delivery")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID, which can be obtained by calling the [ListSites](https://help.aliyun.com/document_detail/2850189.html) interface.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="slsDelivery")
    def sls_delivery(self) -> pulumi.Output[Optional['outputs.SiteDeliveryTaskSlsDelivery']]:
        """
        SLS delivery configuration. See `sls_delivery` below.
        """
        return pulumi.get(self, "sls_delivery")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Task status, value:
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="taskName")
    def task_name(self) -> pulumi.Output[builtins.str]:
        """
        The task name.
        """
        return pulumi.get(self, "task_name")

